#include <iostream>

#include "paths.h"
#include "path_provider.h"

boost::filesystem::path PathProvider::getProfileDir(const std::string & profile) const {
    boost::filesystem::path result(getHomeDir() / profile); // .config/appname ?
    try {
        boost::filesystem::create_directory(result);
    }
    catch (const boost::filesystem::filesystem_error & e) {
        std::cerr << "Failed to create profile dir ('" << result.string() << "'): " << e.what() << std::endl;
    }
    return result;
}

boost::filesystem::path PathProvider::getResourcePath(const std::string & res) const {
    std::vector<boost::filesystem::path> paths(getResourceDirs());
    std::vector<boost::filesystem::path>::iterator it(paths.begin());
    while (it != paths.end()) {
        boost::filesystem::path path(*it / res);
        if (boost::filesystem::exists(path)) {
            return path;
        }
        ++it;
    }
    return boost::filesystem::path();
}

boost::filesystem::path PathProvider::getExecDir() const {
    return Paths::getExecPath();
}
