#include <cstdlib>
#include <iostream>

#include <boost/algorithm/string.hpp>

#include "unix_path_provider.h"

namespace {

class is_char {
    public:
        is_char(char c) : ch(c) {}
        bool operator()(char c) const { return ch == c; }
    private:
        char ch;
};

}

UnixPathProvider::UnixPathProvider(const std::string& name)
    : PathProvider(name)
{
    const std::string suffix(boost::to_lower_copy(getAppName()));
    resDirs.push_back(getExecDir() / ".."); // Development
    char * xdgDataDirs = getenv("XDG_DATA_DIRS");
    if (xdgDataDirs) {
        std::vector<std::string> dataDirs;
        boost::algorithm::split(dataDirs, xdgDataDirs, is_char(':'), boost::algorithm::token_compress_on);
        if (!dataDirs.empty()) {
            std::vector<std::string>::iterator it(dataDirs.begin());
            while (it != dataDirs.end()) {
                resDirs.push_back(boost::filesystem::path(*it++) / suffix);
            }
            return;
        }
    }
    resDirs.push_back("/usr/local/share/" + suffix);
    resDirs.push_back("/usr/share/" + suffix);
}

boost::filesystem::path UnixPathProvider::getHomeDir() const {
    return boost::filesystem::path(getenv("HOME"));
}

boost::filesystem::path UnixPathProvider::getDataDir() const {
    const char * dataDir = getenv("XDG_DATA_HOME");
    boost::filesystem::path path;
    if (dataDir == NULL) {
        path = getHomeDir() / ".local" / "share";
    } else {
        path = boost::filesystem::path(dataDir);
    }

    path = path / boost::to_lower_copy(getAppName());

    try {
        boost::filesystem::create_directories(path);
    }
    catch (const boost::filesystem::filesystem_error & e) {
        std::cerr << "Failed to create data dir ('" << path.string() << "'): " << e.what() << std::endl;
    }

    return path;
}
