/*
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 1, or (at your option)
** any later version.

** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.

** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef __IA_SETTINGS_WINDOW_H__
#define __IA_SETTINGS_WINDOW_H__

#include <boost/cstdint.hpp>

#include <QDialog>
#include <QGridLayout>
#include <QGroupBox>
#include <QButtonGroup>
#include <QLabel>
#include <QLineEdit>
#include <QVBoxLayout>
#include <QHBoxLayout>
#include <QRadioButton>
#include <QCheckBox>
#include <QComboBox>
#include <QPushButton>

class IASettingsWindow : public QDialog {
    Q_OBJECT
public:
    IASettingsWindow(QWidget * parent = 0, Qt::WindowFlags flags = 0);
    virtual ~IASettingsWindow() {};

    void setDirNames(const QStringList & dirNames) { dirsFld->addItems(dirNames); };

    void setServerName(const QString & name) { nameFld->setText(name); }
    void setServerPort(boost::uint16_t p) { portFld->setText(QString::number(p)); }
    void setLogin(const QString & login) { loginFld->setText(login); }
    void setPassword(const QString & password) { passwordFld->setText(password); }
    void setUnits(int u);
    void setFormat(int f);
    void setFlashWarning(bool flag) { flashCB->setChecked(flag); }
    void setMinCashWarning(double cash) { minCashFld->setText(QString::number(cash, 'f', 2)); }
    void setAutoconnect(bool flag) { autoCB->setChecked(flag); }
    void setSavePassword(bool flag) { savePWCB->setChecked(flag); }
    void setReconnect(bool flag) { reconnectCB->setChecked(flag); }
    void setLinkHDD(bool flag) { linkHDDCB->setChecked(flag); }
    void setMinimize(bool flag) { minimizeCB->setChecked(flag); }
    void setMinimizeStart(bool flag) { minimizeStartCB->setChecked(flag); }
    void setCashHint(bool flag) { cashHintCB->setChecked(flag); }
    void setTraffHint(bool flag) { traffHintCB->setChecked(flag); }
    void setHintDir(int dir) { dirsFld->setCurrentIndex(dir); }
    
    QString getServerName() const { return nameFld->text(); }
    boost::uint16_t getServerPort() const { return portFld->text().toUInt(); }
    QString getLogin() const { return loginFld->text(); }
    QString getPassword() const { return passwordFld->text(); }
    int getUnits() const { return unitsButtonGroup->checkedId(); }
    int getFormat() const { return formatButtonGroup->checkedId(); }
    bool getFlashWarning() const { return flashCB->isChecked(); }
    double getMinCashWarning() const { return minCashFld->text().toDouble(); }
    bool getAutoconnect() const { return autoCB->isChecked(); }
    bool getSavePassword() const { return savePWCB->isChecked(); }
    bool getReconnect() const { return reconnectCB->isChecked(); }
    bool getLinkHDD() const { return linkHDDCB->isChecked(); }
    bool getMinimize() const { return minimizeCB->isChecked(); }
    bool getMinimizeStart() const { return minimizeStartCB->isChecked(); }
    bool getCashHint() const { return cashHintCB->isChecked(); }
    bool getTraffHint() const { return traffHintCB->isChecked(); }
    int getHintDir() const { return dirsFld->currentIndex(); }

private:
    QGridLayout * mainLayout;
    QGroupBox * serverGroup;
    QGridLayout * sgPanel;
    QLabel * nameLbl;
    QLineEdit * nameFld;
    QLabel * portLbl;
    QLineEdit * portFld;
    QLabel * loginLbl;
    QLineEdit * loginFld;
    QLabel * passwordLbl;
    QLineEdit * passwordFld;
    QGroupBox * statGroup;
    QHBoxLayout * statPanel;
    QGroupBox * unitsGroup;
    QButtonGroup * unitsButtonGroup;
    QVBoxLayout * unitsPanel;
    QRadioButton * bBtn;
    QRadioButton * kbBtn;
    QRadioButton * mbBtn;
    QRadioButton * floatingBtn;
    QGroupBox * formatGroup;
    QButtonGroup * formatButtonGroup;
    QVBoxLayout * formatPanel;
    QRadioButton * upplusdownBtn;
    QRadioButton * downBtn;
    QRadioButton * updownBtn;
    QGroupBox * warningGroup;
    QHBoxLayout * warningPanel;
    QCheckBox * flashCB;
    QLineEdit * minCashFld;
    QGroupBox * otherGroup;
    QVBoxLayout * otherPanel;
    QCheckBox * autoCB;
    QCheckBox * savePWCB;
    QCheckBox * reconnectCB;
    QCheckBox * linkHDDCB;
    QCheckBox * minimizeCB;
    QCheckBox * minimizeStartCB;
    QGroupBox * hintGroup;
    QVBoxLayout * hintPanel;
    QCheckBox * cashHintCB;
    QCheckBox * traffHintCB;
    QLabel * dirLbl;
    QComboBox * dirsFld;
};

#endif
